// Copyright (c) 2005..2010 Dirk Jagdmann <doj@cubic.org>

// This software is provided 'as-is', without any express or implied
// warranty. In no event will the authors be held liable for any damages
// arising from the use of this software.

// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:

//     1. The origin of this software must not be misrepresented; you
//        must not claim that you wrote the original software. If you use
//        this software in a product, an acknowledgment in the product
//        documentation would be appreciated but is not required.

//     2. Altered source versions must be plainly marked as such, and
//        must not be misrepresented as being the original software.

//     3. This notice may not be removed or altered from any source
//        distribution.

#include <stdint.h>
namespace {
const char* type2string(uint16_t type)
{
  switch(type)
    {
    case 0x0000: return "WAVE_FORMAT_UNKNOWN - Microsoft Corporation";
    case 0x0001: return "WAVE_FORMAT_PCM";
    case 0x0002: return "WAVE_FORMAT_ADPCM - Microsoft Corporation";
    case 0x0003: return "WAVE_FORMAT_IEEE_FLOAT - Microsoft Corporation";
    case 0x0004: return "WAVE_FORMAT_VSELP - Compaq Computer Corp.";
    case 0x0005: return "WAVE_FORMAT_IBM_CVSD - IBM Corporation";
    case 0x0006: return "WAVE_FORMAT_ALAW - Microsoft Corporation";
    case 0x0007: return "WAVE_FORMAT_MULAW - Microsoft Corporation";
    case 0x0008: return "WAVE_FORMAT_DTS - Microsoft Corporation";
    case 0x0009: return "WAVE_FORMAT_DRM - Microsoft Corporation";
    case 0x0010: return "WAVE_FORMAT_OKI_ADPCM - OKI";
    case 0x0011: return "WAVE_FORMAT_DVI_ADPCM - Intel Corporation";
    case 0x0012: return "WAVE_FORMAT_MEDIASPACE_ADPCM - Videologic";
    case 0x0013: return "WAVE_FORMAT_SIERRA_ADPCM - Sierra Semiconductor Corp";
    case 0x0014: return "WAVE_FORMAT_G723_ADPCM - Antex Electronics Corporation";
    case 0x0015: return "WAVE_FORMAT_DIGISTD - DSP Solutions, Inc.";
    case 0x0016: return "WAVE_FORMAT_DIGIFIX - DSP Solutions, Inc.";
    case 0x0017: return "WAVE_FORMAT_DIALOGIC_OKI_ADPCM - Dialogic Corporation";
    case 0x0018: return "WAVE_FORMAT_MEDIAVISION_ADPCM - Media Vision, Inc.";
    case 0x0019: return "WAVE_FORMAT_CU_CODEC - Hewlett-Packard Company";
    case 0x0020: return "WAVE_FORMAT_YAMAHA_ADPCM - Yamaha Corporation of America";
    case 0x0021: return "WAVE_FORMAT_SONARC - Speech Compression";
    case 0x0022: return "WAVE_FORMAT_DSPGROUP_TRUESPEECH - DSP Group, Inc";
    case 0x0023: return "WAVE_FORMAT_ECHOSC1 - Echo Speech Corporation";
    case 0x0024: return "WAVE_FORMAT_AUDIOFILE_AF36 - Virtual Music, Inc.";
    case 0x0025: return "WAVE_FORMAT_APTX - Audio Processing Technology";
    case 0x0026: return "WAVE_FORMAT_AUDIOFILE_AF10 - Virtual Music, Inc.";
    case 0x0027: return "WAVE_FORMAT_PROSODY_1612 - Aculab plc";
    case 0x0028: return "WAVE_FORMAT_LRC - Merging Technologies S.A.";
    case 0x0030: return "WAVE_FORMAT_DOLBY_AC2 - Dolby Laboratories";
    case 0x0031: return "WAVE_FORMAT_GSM610 - Microsoft Corporation";
    case 0x0032: return "WAVE_FORMAT_MSNAUDIO - Microsoft Corporation";
    case 0x0033: return "WAVE_FORMAT_ANTEX_ADPCME - Antex Electronics Corporation";
    case 0x0034: return "WAVE_FORMAT_CONTROL_RES_VQLPC - Control Resources Limited";
    case 0x0035: return "WAVE_FORMAT_DIGIREAL - DSP Solutions, Inc.";
    case 0x0036: return "WAVE_FORMAT_DIGIADPCM - DSP Solutions, Inc.";
    case 0x0037: return "WAVE_FORMAT_CONTROL_RES_CR10 - Control Resources Limited";
    case 0x0038: return "WAVE_FORMAT_NMS_VBXADPCM - Natural MicroSystems";
    case 0x0039: return "WAVE_FORMAT_CS_IMAADPCM - Crystal Semiconductor IMA ADPCM";
    case 0x003A: return "WAVE_FORMAT_ECHOSC3 - Echo Speech Corporation";
    case 0x003B: return "WAVE_FORMAT_ROCKWELL_ADPCM - Rockwell International";
    case 0x003C: return "WAVE_FORMAT_ROCKWELL_DIGITALK - Rockwell International";
    case 0x003D: return "WAVE_FORMAT_XEBEC - Xebec Multimedia Solutions Limited";
    case 0x0040: return "WAVE_FORMAT_G721_ADPCM - Antex Electronics Corporation";
    case 0x0041: return "WAVE_FORMAT_G728_CELP - Antex Electronics Corporation";
    case 0x0042: return "WAVE_FORMAT_MSG723 - Microsoft Corporation";
    case 0x0050: return "WAVE_FORMAT_MPEG - Microsoft Corporation";
    case 0x0052: return "WAVE_FORMAT_RT24 - InSoft, Inc.";
    case 0x0053: return "WAVE_FORMAT_PAC - InSoft, Inc.";
    case 0x0055: return "WAVE_FORMAT_MPEGLAYER3 - ISO/MPEG Layer3 Format Tag";
    case 0x0059: return "WAVE_FORMAT_LUCENT_G723 - Lucent Technologies";
    case 0x0060: return "WAVE_FORMAT_CIRRUS - Cirrus Logic";
    case 0x0061: return "WAVE_FORMAT_ESPCM - ESS Technology";
    case 0x0062: return "WAVE_FORMAT_VOXWARE - Voxware Inc";
    case 0x0063: return "WAVE_FORMAT_CANOPUS_ATRAC - Canopus, co., Ltd.";
    case 0x0064: return "WAVE_FORMAT_G726_ADPCM - APICOM";
    case 0x0065: return "WAVE_FORMAT_G722_ADPCM - APICOM";
    case 0x0067: return "WAVE_FORMAT_DSAT_DISPLAY - Microsoft Corporation";
    case 0x0069: return "WAVE_FORMAT_VOXWARE_BYTE_ALIGNED - Voxware Inc";
    case 0x0070: return "WAVE_FORMAT_VOXWARE_AC8 - Voxware Inc";
    case 0x0071: return "WAVE_FORMAT_VOXWARE_AC10 - Voxware Inc";
    case 0x0072: return "WAVE_FORMAT_VOXWARE_AC16 - Voxware Inc";
    case 0x0073: return "WAVE_FORMAT_VOXWARE_AC20 - Voxware Inc";
    case 0x0074: return "WAVE_FORMAT_VOXWARE_RT24 - Voxware Inc";
    case 0x0075: return "WAVE_FORMAT_VOXWARE_RT29 - Voxware Inc";
    case 0x0076: return "WAVE_FORMAT_VOXWARE_RT29HW - Voxware Inc";
    case 0x0077: return "WAVE_FORMAT_VOXWARE_VR12 - Voxware Inc";
    case 0x0078: return "WAVE_FORMAT_VOXWARE_VR18 - Voxware Inc";
    case 0x0079: return "WAVE_FORMAT_VOXWARE_TQ40 - Voxware Inc";
    case 0x0080: return "WAVE_FORMAT_SOFTSOUND - Softsound, Ltd.";
    case 0x0081: return "WAVE_FORMAT_VOXWARE_TQ60 - Voxware Inc";
    case 0x0082: return "WAVE_FORMAT_MSRT24 - Microsoft Corporation";
    case 0x0083: return "WAVE_FORMAT_G729A - AT&T Labs, Inc.";
    case 0x0084: return "WAVE_FORMAT_MVI_MVI2 - Motion Pixels";
    case 0x0085: return "WAVE_FORMAT_DF_G726 - DataFusion Systems (Pty) (Ltd)";
    case 0x0086: return "WAVE_FORMAT_DF_GSM610 - DataFusion Systems (Pty) (Ltd)";
    case 0x0088: return "WAVE_FORMAT_ISIAUDIO - Iterated Systems, Inc.";
    case 0x0089: return "WAVE_FORMAT_ONLIVE - OnLive! Technologies, Inc.";
    case 0x0091: return "WAVE_FORMAT_SBC24 - Siemens Business Communications Sys";
    case 0x0092: return "WAVE_FORMAT_DOLBY_AC3_SPDIF - Sonic Foundry";
    case 0x0093: return "WAVE_FORMAT_MEDIASONIC_G723 - MediaSonic";
    case 0x0094: return "WAVE_FORMAT_PROSODY_8KBPS - Aculab plc";
    case 0x0097: return "WAVE_FORMAT_ZYXEL_ADPCM - ZyXEL Communications, Inc.";
    case 0x0098: return "WAVE_FORMAT_PHILIPS_LPCBB - Philips Speech Processing";
    case 0x0099: return "WAVE_FORMAT_PACKED - Studer Professional Audio AG";
    case 0x00A0: return "WAVE_FORMAT_MALDEN_PHONYTALK - Malden Electronics Ltd.";
    case 0x0100: return "WAVE_FORMAT_RHETOREX_ADPCM - Rhetorex Inc.";
    case 0x0101: return "WAVE_FORMAT_IRAT - BeCubed Software Inc.";
    case 0x0111: return "WAVE_FORMAT_VIVO_G723 - Vivo Software";
    case 0x0112: return "WAVE_FORMAT_VIVO_SIREN - Vivo Software";
    case 0x0123: return "WAVE_FORMAT_DIGITAL_G723 - Digital Equipment Corporation";
    case 0x0125: return "WAVE_FORMAT_SANYO_LD_ADPCM - Sanyo Electric Co., Ltd.";
    case 0x0130: return "WAVE_FORMAT_SIPROLAB_ACEPLNET - Sipro Lab Telecom Inc.";
    case 0x0131: return "WAVE_FORMAT_SIPROLAB_ACELP4800 - Sipro Lab Telecom Inc.";
    case 0x0132: return "WAVE_FORMAT_SIPROLAB_ACELP8V3 - Sipro Lab Telecom Inc.";
    case 0x0133: return "WAVE_FORMAT_SIPROLAB_G729 - Sipro Lab Telecom Inc.";
    case 0x0134: return "WAVE_FORMAT_SIPROLAB_G729A - Sipro Lab Telecom Inc.";
    case 0x0135: return "WAVE_FORMAT_SIPROLAB_KELVIN - Sipro Lab Telecom Inc.";
    case 0x0140: return "WAVE_FORMAT_G726ADPCM - Dictaphone Corporation";
    case 0x0150: return "WAVE_FORMAT_QUALCOMM_PUREVOICE - Qualcomm, Inc.";
    case 0x0151: return "WAVE_FORMAT_QUALCOMM_HALFRATE - Qualcomm, Inc.";
    case 0x0155: return "WAVE_FORMAT_TUBGSM - Ring Zero Systems, Inc.";
    case 0x0160: return "WAVE_FORMAT_MSAUDIO1 - Microsoft Corporation";
    case 0x0170: return "WAVE_FORMAT_UNISYS_NAP_ADPCM - Unisys Corp.";
    case 0x0171: return "WAVE_FORMAT_UNISYS_NAP_ULAW - Unisys Corp.";
    case 0x0172: return "WAVE_FORMAT_UNISYS_NAP_ALAW - Unisys Corp.";
    case 0x0173: return "WAVE_FORMAT_UNISYS_NAP_16K - Unisys Corp.";
    case 0x0200: return "WAVE_FORMAT_CREATIVE_ADPCM - Creative Labs, Inc";
    case 0x0202: return "WAVE_FORMAT_CREATIVE_FASTSPEECH8 - Creative Labs, Inc";
    case 0x0203: return "WAVE_FORMAT_CREATIVE_FASTSPEECH10 - Creative Labs, Inc";
    case 0x0210: return "WAVE_FORMAT_UHER_ADPCM - UHER informatic GmbH";
    case 0x0220: return "WAVE_FORMAT_QUARTERDECK - Quarterdeck Corporation";
    case 0x0230: return "WAVE_FORMAT_ILINK_VC - I-link Worldwide";
    case 0x0240: return "WAVE_FORMAT_RAW_SPORT - Aureal Semiconductor";
    case 0x0241: return "WAVE_FORMAT_ESST_AC3 - ESS Technology, Inc.";
    case 0x0250: return "WAVE_FORMAT_IPI_HSX - Interactive Products, Inc.";
    case 0x0251: return "WAVE_FORMAT_IPI_RPELP - Interactive Products, Inc.";
    case 0x0260: return "WAVE_FORMAT_CS2 - Consistent Software";
    case 0x0270: return "WAVE_FORMAT_SONY_SCX - Sony Corp.";
    case 0x0300: return "WAVE_FORMAT_FM_TOWNS_SND - Fujitsu Corp.";
    case 0x0400: return "WAVE_FORMAT_BTV_DIGITAL - Brooktree Corporation";
    case 0x0450: return "WAVE_FORMAT_QDESIGN_MUSIC - QDesign Corporation";
    case 0x0680: return "WAVE_FORMAT_VME_VMPCM - AT&T Labs, Inc.";
    case 0x0681: return "WAVE_FORMAT_TPC - AT&T Labs, Inc.";
    case 0x1000: return "WAVE_FORMAT_OLIGSM - Ing C. Olivetti & C., S.p.A.";
    case 0x1001: return "WAVE_FORMAT_OLIADPCM - Ing C. Olivetti & C., S.p.A.";
    case 0x1002: return "WAVE_FORMAT_OLICELP - Ing C. Olivetti & C., S.p.A.";
    case 0x1003: return "WAVE_FORMAT_OLISBC - Ing C. Olivetti & C., S.p.A.";
    case 0x1004: return "WAVE_FORMAT_OLIOPR - Ing C. Olivetti & C., S.p.A.";
    case 0x1100: return "WAVE_FORMAT_LH_CODEC - Lernout & Hauspie";
    case 0x1400: return "WAVE_FORMAT_NORRIS - Norris Communications, Inc.";
    case 0x1500: return "WAVE_FORMAT_SOUNDSPACE_MUSICOMPRESS - AT&T Labs, Inc.";
    case 0x2000: return "WAVE_FORMAT_DVM - FAST Multimedia AG";
    case 0xFFFE: return "WAVE_FORMAT_EXTENSIBLE - Microsoft";
    case 0xFFFF: return "WAVE_FORMAT_DEVELOPMENT";
    }
  return "unknown WAVE format";
}

} // namespace
